@@ -534,40 +534,40 @@ std::string DateTimeExpression::toIsoString(char dateDelimiter, char timeDelimit
 {
     auto s = std::stringstream(std::stringstream::in | std::stringstream::out);
     s << setfill('0');
-    if (parts & DateTimeParts::Year) {
+    if (parts && DateTimeParts::Year) {
         s << setw(4) << value.year();
     }
-    if (parts & DateTimeParts::Month) {
+    if (parts && DateTimeParts::Month) {
         if (s.tellp()) {
             s << dateDelimiter;
         }
         s << setw(2) << value.month();
     }
-    if (parts & DateTimeParts::Day) {
+    if (parts && DateTimeParts::Day) {
         if (s.tellp()) {
             s << dateDelimiter;
         }
         s << setw(2) << value.day();
     }
-    if (parts & DateTimeParts::Hour) {
+    if (parts && DateTimeParts::Hour) {
         if (s.tellp()) {
             s << 'T';
         }
         s << setw(2) << value.hour();
     }
-    if (parts & DateTimeParts::Minute) {
+    if (parts && DateTimeParts::Minute) {
         if (s.tellp()) {
             s << timeDelimiter;
         }
         s << setw(2) << value.minute();
     }
-    if (parts & DateTimeParts::Second) {
+    if (parts && DateTimeParts::Second) {
         if (s.tellp()) {
             s << timeDelimiter;
         }
         s << setw(2) << value.second();
     }
-    if (parts & DateTimeParts::SubSecond) {
+    if (parts && DateTimeParts::SubSecond) {
         const auto milli = value.millisecond();
         const auto micro = value.microsecond();
         const auto nano = value.nanosecond();
@@ -579,7 +579,7 @@ std::string DateTimeExpression::toIsoString(char dateDelimiter, char timeDelimit
             }
         }
     }
-    if (parts & DateTimeParts::TimeZoneDelta) {
+    if (parts && DateTimeParts::TimeZoneDelta) {
         auto d = delta;
         if (d.isNegative()) {
             s << '-';
@@ -587,11 +587,11 @@ std::string DateTimeExpression::toIsoString(char dateDelimiter, char timeDelimit
         } else {
             s << '+';
         }
-        if (parts & DateTimeParts::DeltaHour) {
+        if (parts && DateTimeParts::DeltaHour) {
             s << setw(2) << d.hours();
         }
-        if (parts & DateTimeParts::DeltaMinute) {
-            if (parts & DateTimeParts::DeltaHour) {
+        if (parts && DateTimeParts::DeltaMinute) {
+            if (parts && DateTimeParts::DeltaHour) {
                 s << timeZoneDelimiter;
             }
             s << setw(2) << d.minutes();
