@@ -27,19 +27,17 @@
 
 namespace CppUtilities {
 
+// clang-format off
 /*!
  * \brief The StringDataDeleter struct deletes the data of a StringData instance.
  */
-struct CPP_UTILITIES_EXPORT StringDataDeleter {
-    /*!
+struct CPP_UTILITIES_EXPORT StringDataDeleter{ /*!
      * \brief Deletes the specified \a stringData with std::free(), because the memory has been
      *        allocated using std::malloc()/std::realloc().
      */
-    void operator()(char *stringData)
-    {
-        std::free(stringData);
-    }
+    void operator()(char *stringData){ std::free(stringData); }
 };
+// clang-format on
 
 /*!
  * \brief Type used to return string encoding conversion result.
@@ -47,6 +45,7 @@ struct CPP_UTILITIES_EXPORT StringDataDeleter {
 using StringData = std::pair<std::unique_ptr<char[], StringDataDeleter>, std::size_t>;
 //using StringData = std::pair<std::unique_ptr<char>, std::size_t>; // might work too
 
+#ifndef CPP_UTILITIES_NO_ICONV
 CPP_UTILITIES_EXPORT StringData convertString(
     const char *fromCharset, const char *toCharset, const char *inputBuffer, std::size_t inputBufferSize, float outputBufferSizeFactor = 1.0f);
 CPP_UTILITIES_EXPORT StringData convertUtf8ToUtf16LE(const char *inputBuffer, std::size_t inputBufferSize);
@@ -55,6 +54,7 @@ CPP_UTILITIES_EXPORT StringData convertUtf8ToUtf16BE(const char *inputBuffer, st
 CPP_UTILITIES_EXPORT StringData convertUtf16BEToUtf8(const char *inputBuffer, std::size_t inputBufferSize);
 CPP_UTILITIES_EXPORT StringData convertLatin1ToUtf8(const char *inputBuffer, std::size_t inputBufferSize);
 CPP_UTILITIES_EXPORT StringData convertUtf8ToLatin1(const char *inputBuffer, std::size_t inputBufferSize);
+#endif
 
 #ifdef PLATFORM_WINDOWS
 using WideStringData = std::pair<std::unique_ptr<wchar_t[]>, int>;
@@ -302,7 +302,7 @@ template <typename StringType> bool endsWith(const StringType &str, const String
         return false;
     }
     for (auto stri = str.cend() - static_cast<typename StringType::difference_type>(phrase.size()), strend = str.cend(), phrasei = phrase.cbegin();
-         stri != strend; ++stri, ++phrasei) {
+        stri != strend; ++stri, ++phrasei) {
         if (*stri != *phrasei) {
             return false;
         }
@@ -320,7 +320,7 @@ template <typename StringType> bool endsWith(const StringType &str, const typena
         return false;
     }
     for (auto stri = str.cend() - static_cast<typename StringType::difference_type>(phraseSize), strend = str.cend(); stri != strend;
-         ++stri, ++phrase) {
+        ++stri, ++phrase) {
         if (*stri != *phrase) {
             return false;
         }
@@ -421,13 +421,16 @@ template <typename IntegralType, class StringType = std::string, typename BaseTy
     CppUtilities::Traits::EnableIf<std::is_integral<IntegralType>, std::is_unsigned<IntegralType>> * = nullptr>
 StringType numberToString(IntegralType number, BaseType base = 10)
 {
-    std::size_t resSize = 0;
-    for (auto n = number; n; n /= static_cast<IntegralType>(base), ++resSize)
-        ;
-    StringType res;
-    res.reserve(resSize);
+    auto resSize = std::size_t();
+    auto n = number;
     do {
-        res.insert(res.begin(), digitToChar<typename StringType::value_type>(static_cast<typename StringType::value_type>(number % base)));
+        n /= static_cast<IntegralType>(base), ++resSize;
+    } while (n);
+    auto res = StringType(resSize, typename StringType::value_type());
+    auto resIter = res.end();
+    do {
+        *(--resIter)
+            = digitToChar<typename StringType::value_type>(static_cast<typename StringType::value_type>(number % static_cast<IntegralType>(base)));
         number /= static_cast<IntegralType>(base);
     } while (number);
     return res;
@@ -443,24 +446,24 @@ template <typename IntegralType, class StringType = std::string, typename BaseTy
     Traits::EnableIf<std::is_integral<IntegralType>, std::is_signed<IntegralType>> * = nullptr>
 StringType numberToString(IntegralType number, BaseType base = 10)
 {
-    const bool negative = number < 0;
-    std::size_t resSize;
+    const auto negative = number < 0;
+    auto resSize = std::size_t();
     if (negative) {
         number = -number, resSize = 1;
-    } else {
-        resSize = 0;
     }
-    for (auto n = number; n; n /= static_cast<IntegralType>(base), ++resSize)
-        ;
-    StringType res;
-    res.reserve(resSize);
+    auto n = number;
     do {
-        res.insert(res.begin(),
-            digitToChar<typename StringType::value_type>(static_cast<typename StringType::value_type>(number % static_cast<IntegralType>(base))));
+        n /= static_cast<IntegralType>(base), ++resSize;
+    } while (n);
+    auto res = StringType(resSize, typename StringType::value_type());
+    auto resIter = res.end();
+    do {
+        *(--resIter)
+            = digitToChar<typename StringType::value_type>(static_cast<typename StringType::value_type>(number % static_cast<IntegralType>(base)));
         number /= static_cast<IntegralType>(base);
     } while (number);
     if (negative) {
-        res.insert(res.begin(), '-');
+        *(--resIter) = '-';
     }
     return res;
 }
@@ -487,7 +490,7 @@ StringType numberToString(FloatingType number, int base = 10)
  */
 template <typename CharType> CharType charToDigit(CharType character, CharType base)
 {
-    CharType res = base;
+    auto res = base;
     if (character >= '0' && character <= '9') {
         res = character - '0';
     } else if (character >= 'a' && character <= 'z') {
@@ -498,11 +501,13 @@ template <typename CharType> CharType charToDigit(CharType character, CharType b
     if (res < base) {
         return res;
     }
-    std::string errorMsg;
-    errorMsg.reserve(36);
-    errorMsg += "The character \"";
+    constexpr auto msgBegin = std::string_view("The character \"");
+    constexpr auto msgEnd = std::string_view("\" is no valid digit.");
+    auto errorMsg = std::string();
+    errorMsg.reserve(msgBegin.size() + msgEnd.size() + 2);
+    errorMsg += msgBegin;
     errorMsg += character >= ' ' && character <= '~' ? static_cast<std::string::value_type>(character) : '?';
-    errorMsg += "\" is no valid digit.";
+    errorMsg += msgEnd;
     throw ConversionException(std::move(errorMsg));
 }
 
