@@ -243,7 +243,7 @@ inline void BinaryReader::read(std::vector<char> &buffer, std::streamsize length
 inline std::int16_t BinaryReader::readInt16BE()
 {
     m_stream->read(m_buffer, sizeof(std::int16_t));
-    return BE::toInt16(m_buffer);
+    return BE::toInt<std::int16_t>(m_buffer);
 }
 
 /*!
@@ -252,7 +252,7 @@ inline std::int16_t BinaryReader::readInt16BE()
 inline std::uint16_t BinaryReader::readUInt16BE()
 {
     m_stream->read(m_buffer, sizeof(std::uint16_t));
-    return BE::toUInt16(m_buffer);
+    return BE::toInt<std::uint16_t>(m_buffer);
 }
 
 /*!
@@ -262,7 +262,7 @@ inline std::int32_t BinaryReader::readInt24BE()
 {
     *m_buffer = 0;
     m_stream->read(m_buffer + 1, 3);
-    auto val = BE::toInt32(m_buffer);
+    auto val = BE::toInt<std::int32_t>(m_buffer);
     if (val >= 0x800000) {
         val = -(0x1000000 - val);
     }
@@ -276,7 +276,7 @@ inline std::uint32_t BinaryReader::readUInt24BE()
 {
     *m_buffer = 0;
     m_stream->read(m_buffer + 1, 3);
-    return BE::toUInt32(m_buffer);
+    return BE::toInt<std::uint32_t>(m_buffer);
 }
 
 /*!
@@ -285,7 +285,7 @@ inline std::uint32_t BinaryReader::readUInt24BE()
 inline std::int32_t BinaryReader::readInt32BE()
 {
     m_stream->read(m_buffer, sizeof(std::int32_t));
-    return BE::toInt32(m_buffer);
+    return BE::toInt<std::int32_t>(m_buffer);
 }
 
 /*!
@@ -294,7 +294,7 @@ inline std::int32_t BinaryReader::readInt32BE()
 inline std::uint32_t BinaryReader::readUInt32BE()
 {
     m_stream->read(m_buffer, sizeof(std::uint32_t));
-    return BE::toUInt32(m_buffer);
+    return BE::toInt<std::uint32_t>(m_buffer);
 }
 
 /*!
@@ -304,7 +304,7 @@ inline std::int64_t BinaryReader::readInt40BE()
 {
     *m_buffer = *(m_buffer + 1) = *(m_buffer + 2) = 0;
     m_stream->read(m_buffer + 3, 5);
-    auto val = BE::toInt64(m_buffer);
+    auto val = BE::toInt<std::int64_t>(m_buffer);
     if (val >= 0x8000000000) {
         val = -(0x10000000000 - val);
     }
@@ -318,7 +318,7 @@ inline std::uint64_t BinaryReader::readUInt40BE()
 {
     *m_buffer = *(m_buffer + 1) = *(m_buffer + 2) = 0;
     m_stream->read(m_buffer + 3, 5);
-    return BE::toUInt64(m_buffer);
+    return BE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -328,7 +328,7 @@ inline std::int64_t BinaryReader::readInt56BE()
 {
     *m_buffer = 0;
     m_stream->read(m_buffer + 1, 7);
-    auto val = BE::toInt64(m_buffer);
+    auto val = BE::toInt<std::int64_t>(m_buffer);
     if (val >= 0x80000000000000) {
         val = -(0x100000000000000 - val);
     }
@@ -342,7 +342,7 @@ inline std::uint64_t BinaryReader::readUInt56BE()
 {
     *m_buffer = 0;
     m_stream->read(m_buffer + 1, 7);
-    return BE::toUInt64(m_buffer);
+    return BE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -351,7 +351,7 @@ inline std::uint64_t BinaryReader::readUInt56BE()
 inline std::int64_t BinaryReader::readInt64BE()
 {
     m_stream->read(m_buffer, sizeof(std::int64_t));
-    return BE::toInt64(m_buffer);
+    return BE::toInt<std::int64_t>(m_buffer);
 }
 
 /*!
@@ -360,7 +360,7 @@ inline std::int64_t BinaryReader::readInt64BE()
 inline std::uint64_t BinaryReader::readUInt64BE()
 {
     m_stream->read(m_buffer, sizeof(std::uint64_t));
-    return BE::toUInt64(m_buffer);
+    return BE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -370,7 +370,7 @@ inline std::uint64_t BinaryReader::readUInt64BE()
 inline std::uint64_t BinaryReader::readVariableLengthUIntBE()
 {
     bufferVariableLengthInteger();
-    return BE::toUInt64(m_buffer);
+    return BE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -397,7 +397,7 @@ inline double BinaryReader::readFloat64BE()
 inline std::int16_t BinaryReader::readInt16LE()
 {
     m_stream->read(m_buffer, sizeof(std::int16_t));
-    return LE::toInt16(m_buffer);
+    return LE::toInt<std::int16_t>(m_buffer);
 }
 
 /*!
@@ -406,7 +406,7 @@ inline std::int16_t BinaryReader::readInt16LE()
 inline std::uint16_t BinaryReader::readUInt16LE()
 {
     m_stream->read(m_buffer, sizeof(std::uint16_t));
-    return LE::toUInt16(m_buffer);
+    return LE::toInt<std::uint16_t>(m_buffer);
 }
 
 /*!
@@ -416,7 +416,7 @@ inline std::int32_t BinaryReader::readInt24LE()
 {
     *(m_buffer + 3) = 0;
     m_stream->read(m_buffer, 3);
-    auto val = LE::toInt32(m_buffer);
+    auto val = LE::toInt<std::int32_t>(m_buffer);
     if (val >= 0x800000) {
         val = -(0x1000000 - val);
     }
@@ -430,7 +430,7 @@ inline std::uint32_t BinaryReader::readUInt24LE()
 {
     *(m_buffer + 3) = 0;
     m_stream->read(m_buffer, 3);
-    return LE::toUInt32(m_buffer);
+    return LE::toInt<std::uint32_t>(m_buffer);
 }
 
 /*!
@@ -439,7 +439,7 @@ inline std::uint32_t BinaryReader::readUInt24LE()
 inline std::int32_t BinaryReader::readInt32LE()
 {
     m_stream->read(m_buffer, sizeof(std::int32_t));
-    return LE::toInt32(m_buffer);
+    return LE::toInt<std::int32_t>(m_buffer);
 }
 
 /*!
@@ -448,7 +448,7 @@ inline std::int32_t BinaryReader::readInt32LE()
 inline std::uint32_t BinaryReader::readUInt32LE()
 {
     m_stream->read(m_buffer, sizeof(std::uint32_t));
-    return LE::toUInt32(m_buffer);
+    return LE::toInt<std::uint32_t>(m_buffer);
 }
 
 /*!
@@ -458,7 +458,7 @@ inline std::int64_t BinaryReader::readInt40LE()
 {
     *(m_buffer + 5) = *(m_buffer + 6) = *(m_buffer + 7) = 0;
     m_stream->read(m_buffer, 5);
-    auto val = LE::toInt64(m_buffer);
+    auto val = LE::toInt<std::int64_t>(m_buffer);
     if (val >= 0x8000000000) {
         val = -(0x10000000000 - val);
     }
@@ -472,7 +472,7 @@ inline std::uint64_t BinaryReader::readUInt40LE()
 {
     *(m_buffer + 5) = *(m_buffer + 6) = *(m_buffer + 7) = 0;
     m_stream->read(m_buffer, 5);
-    return LE::toUInt64(m_buffer);
+    return LE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -482,7 +482,7 @@ inline std::int64_t BinaryReader::readInt56LE()
 {
     *(m_buffer + 7) = 0;
     m_stream->read(m_buffer, 7);
-    auto val = LE::toInt64(m_buffer);
+    auto val = LE::toInt<std::int64_t>(m_buffer);
     if (val >= 0x80000000000000) {
         val = -(0x100000000000000 - val);
     }
@@ -496,7 +496,7 @@ inline std::uint64_t BinaryReader::readUInt56LE()
 {
     *(m_buffer + 7) = 0;
     m_stream->read(m_buffer, 7);
-    return LE::toUInt64(m_buffer);
+    return LE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -505,7 +505,7 @@ inline std::uint64_t BinaryReader::readUInt56LE()
 inline std::int64_t BinaryReader::readInt64LE()
 {
     m_stream->read(m_buffer, sizeof(std::int64_t));
-    return LE::toInt64(m_buffer);
+    return LE::toInt<std::int64_t>(m_buffer);
 }
 
 /*!
@@ -514,7 +514,7 @@ inline std::int64_t BinaryReader::readInt64LE()
 inline std::uint64_t BinaryReader::readUInt64LE()
 {
     m_stream->read(m_buffer, sizeof(std::uint64_t));
-    return LE::toUInt64(m_buffer);
+    return LE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
@@ -524,7 +524,7 @@ inline std::uint64_t BinaryReader::readUInt64LE()
 inline std::uint64_t BinaryReader::readVariableLengthUIntLE()
 {
     bufferVariableLengthInteger();
-    return LE::toUInt64(m_buffer);
+    return LE::toInt<std::uint64_t>(m_buffer);
 }
 
 /*!
