@@ -20,7 +20,11 @@ public:
     void operator()(const std::string_view::value_type *buffer, std::size_t bufferSize);
     template <std::size_t bufferCapacity>
     void operator()(std::shared_ptr<std::array<std::string_view::value_type, bufferCapacity>> buffer, std::size_t bufferSize);
+    const std::string_view::value_type *process(std::string_view buffer);
+    const std::string_view::value_type *process(const std::string_view::value_type *buffer, std::size_t bufferSize);
     void reset();
+    std::string &result();
+    const std::string &result() const;
 
 private:
     const std::string_view m_searchTerm;
@@ -68,6 +72,31 @@ inline void BufferSearch::operator()(std::shared_ptr<std::array<std::string_view
     (*this)(buffer->data(), bufferSize);
 }
 
+/*!
+ * \brief Processes the specified \a buffer. Invokes the callback according to the remarks mentioned in the class documentation.
+ * \returns See other overload for details.
+ */
+inline const std::string_view::value_type *BufferSearch::process(std::string_view buffer)
+{
+    return process(buffer.data(), buffer.size());
+}
+
+/*!
+ * \brief Returns the search result at this point.
+ */
+inline std::string &BufferSearch::result()
+{
+    return m_result;
+}
+
+/*!
+ * \brief Returns the search result at this point.
+ */
+inline const std::string &BufferSearch::result() const
+{
+    return m_result;
+}
+
 } // namespace CppUtilities
 
 #endif // IOUTILITIES_BUFFER_SEARCH_H
