@@ -1,7 +1,10 @@
 #include "./testutils.h"
 
+using namespace CppUtilities;
+
 #include "../conversion/stringconversion.h"
 
+#ifndef CPP_UTILITIES_NO_ICONV
 /*!
  * \brief Allows printing std::wstring using CPPUNIT_ASSERT_EQUAL.
  */
@@ -17,6 +20,7 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
     out.write(utf8.first.get(), static_cast<std::streamsize>(utf8.second));
     return out;
 }
+#endif
 
 #include "../conversion/conversionexception.h"
 #include "../conversion/stringbuilder.h"
@@ -32,10 +36,15 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
 #include "../io/nativefilestream.h"
 #include "../io/path.h"
 
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+#include "../io/archive.h"
+#endif
+
 #include <cppunit/TestFixture.h>
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <algorithm>
+#include <cstddef>
 #include <fstream>
 #include <regex>
 #include <sstream>
@@ -50,7 +59,6 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
 #endif
 
 using namespace std;
-using namespace CppUtilities;
 using namespace CppUtilities::Literals;
 using namespace CPPUNIT_NS;
 
@@ -73,6 +81,9 @@ class IoTests : public TestFixture {
     CPPUNIT_TEST(testAnsiEscapeCodes);
 #ifdef CPP_UTILITIES_USE_NATIVE_FILE_BUFFER
     CPPUNIT_TEST(testNativeFileStream);
+#endif
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+    CPPUNIT_TEST(testExtractingArchive);
 #endif
     CPPUNIT_TEST_SUITE_END();
 
@@ -95,6 +106,9 @@ public:
 #ifdef CPP_UTILITIES_USE_NATIVE_FILE_BUFFER
     void testNativeFileStream();
 #endif
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+    void testExtractingArchive();
+#endif
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(IoTests);
@@ -323,14 +337,14 @@ void IoTests::testBufferSearch()
     bs(buffer, 0);
     CPPUNIT_ASSERT(!hasResult);
     std::strcpy(buffer, "Starting Updated");
-    bs(std::string_view(buffer, 16));
+    CPPUNIT_ASSERT(bs.process(std::string_view(buffer, 16)) == nullptr);
     CPPUNIT_ASSERT(!hasResult);
     std::strcpy(buffer, " version: some ");
     bs(buffer, 15);
     CPPUNIT_ASSERT(!hasResult);
     expectedResult = "some version number";
     std::strcpy(buffer, "version number\tmore chars");
-    bs(buffer, 25);
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::ptrdiff_t>(14), bs.process(buffer, 25) - buffer);
     CPPUNIT_ASSERT(hasResult);
     hasResult = false;
     std::strcpy(buffer, "... Starting build ...");
@@ -359,9 +373,14 @@ void IoTests::testPathUtilities()
     const auto expected = input;
     const auto output = makeNativePath(input);
 #ifdef PLATFORM_WINDOWS
+#ifndef CPP_UTILITIES_NO_ICONV
     const auto outputAsUtf8 = convertUtf16LEToUtf8(reinterpret_cast<const char *>(output.data()), output.size() * 2);
     const auto outputView = std::string_view(outputAsUtf8.first.get(), outputAsUtf8.second);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("makeNativePath()", expected, outputView);
+#else
+    CPP_UTILITIES_UNUSED(expected)
+    CPP_UTILITIES_UNUSED(output)
+#endif
 #else
     CPPUNIT_ASSERT_EQUAL_MESSAGE("makeNativePath()", expected, output);
 #endif
@@ -434,7 +453,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL(7_st, options->fields.size());
     CPPUNIT_ASSERT_EQUAL("HoldPkg"s, options->fields[0].key);
     CPPUNIT_ASSERT_EQUAL("pacman glibc"s, options->fields[0].value);
-    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[0].flags & IniFileFieldFlags::HasValue);
+    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[0].flags && IniFileFieldFlags::HasValue);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block between section header and first field",
         "# The following paths are.*\n.*#HookDir     = /etc/pacman\\.d/hooks/\n"s, std::regex::extended, options->fields[0].precedingCommentBlock);
@@ -442,7 +461,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL(""s, options->fields[0].followingInlineComment);
     CPPUNIT_ASSERT_EQUAL("Foo"s, options->fields[1].key);
     CPPUNIT_ASSERT_EQUAL("bar"s, options->fields[1].value);
-    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[1].flags & IniFileFieldFlags::HasValue);
+    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[1].flags && IniFileFieldFlags::HasValue);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block between fields", "#XferCommand.*\n.*#CleanMethod = KeepInstalled\n"s, std::regex::extended,
         options->fields[1].precedingCommentBlock);
@@ -450,7 +469,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL("# inline comment"s, options->fields[1].followingInlineComment);
     CPPUNIT_ASSERT_EQUAL("CheckSpace"s, options->fields[3].key);
     CPPUNIT_ASSERT_EQUAL(""s, options->fields[3].value);
-    CPPUNIT_ASSERT_MESSAGE("no value present", !(options->fields[3].flags & IniFileFieldFlags::HasValue));
+    CPPUNIT_ASSERT_MESSAGE("no value present", !(options->fields[3].flags && IniFileFieldFlags::HasValue));
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("empty lines in comments preserved", "\n# Pacman.*\n.*\n\n#NoUpgrade   =\n.*#TotalDownload\n"s, std::regex::extended,
         options->fields[3].precedingCommentBlock);
@@ -461,7 +480,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("comment block which is only an empty line", "\n"s, extraScope->precedingCommentBlock);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("inline comment after scope", "# an inline comment after a scope name"s, extraScope->followingInlineComment);
     CPPUNIT_ASSERT_EQUAL(1_st, extraScope->fields.size());
-    CPPUNIT_ASSERT(ini.sections.back().flags & IniFileSectionFlags::Implicit);
+    CPPUNIT_ASSERT(ini.sections.back().flags && IniFileSectionFlags::Implicit);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block after last field present in implicitly added last scope", "\n# If you.*\n.*custompkgs\n"s,
         std::regex::extended, ini.sections.back().precedingCommentBlock);
@@ -769,3 +788,31 @@ void IoTests::testNativeFileStream()
     CPPUNIT_ASSERT_EQUAL("barfoo"s, readFile(txtFilePath, 7));
 }
 #endif
+
+#ifdef CPP_UTILITIES_USE_LIBARCHIVE
+void IoTests::testExtractingArchive()
+{
+    const auto archivePath = testFilePath("archive-test.zip");
+    const auto archiveContents = extractFiles(archivePath);
+    const auto &root = archiveContents.at(std::string());
+    const auto &subdir = archiveContents.at("subdir");
+    const auto &subsubdir = archiveContents.at("subdir/foo");
+
+    CPPUNIT_ASSERT_EQUAL(1_st, root.size());
+    CPPUNIT_ASSERT_EQUAL("test.txt"s, root.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, root.at(0).type);
+    CPPUNIT_ASSERT_EQUAL(DateTime::fromDate(1970, 1, 1), root.at(0).creationTime);
+    CPPUNIT_ASSERT_EQUAL(DateTime::fromDateAndTime(2024, 3, 3, 19, 46, 42), root.at(0).modificationTime);
+    CPPUNIT_ASSERT_EQUAL("testfile\n"s, root.at(0).content);
+
+    CPPUNIT_ASSERT_EQUAL(1_st, subdir.size());
+    CPPUNIT_ASSERT_EQUAL("nested-testfile.txt"s, subdir.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, subdir.at(0).type);
+    CPPUNIT_ASSERT_EQUAL("some file\n"s, subdir.at(0).content);
+
+    CPPUNIT_ASSERT_EQUAL(1_st, subsubdir.size());
+    CPPUNIT_ASSERT_EQUAL("bar"s, subsubdir.at(0).name);
+    CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, subsubdir.at(0).type);
+    CPPUNIT_ASSERT_EQUAL(std::string(), subsubdir.at(0).content);
+}
+#endif
